package com.ynet.life.sujrb.base;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.Trace;
import com.ynet.life.controller.LifeAccessInterface;
import com.ynet.life.controller.LifeClientRequest;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.formValidation.FormValidationProvider;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/PBLogonAccessController.class */
public class PBLogonAccessController implements LifeAccessInterface {
    public void checkSubmitTimestamp(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String requestTimestamp = request.getParameter(LifeConstants.FIELD_SUBMIT_TIMESTAMP);
            if (requestTimestamp != null) {
                String lastTimestamp = (String) sessionContext.getDataValue(LifeConstants.FIELD_SUBMIT_TIMESTAMP);
                if (lastTimestamp != null && lastTimestamp.equals(requestTimestamp)) {
                    Trace.logWarning("LifeAction", "EBLN8000::重复提交异常");
                    throw LifeConstants.EXCEPTION_DUPLICATE_SUBMIT;
                }
                sessionContext.setDataValue(LifeConstants.FIELD_SUBMIT_TIMESTAMP, requestTimestamp);
            }
        } catch (TranFailException ex) {
            Trace.logError("LifeAction", "EBLN8000::重复提交异常", ex);
            throw ex;
        } catch (GENEException ex2) {
            Trace.logError("LifeAction", "时间戳错误", ex2);
        }
    }

    public void checkUserPrivilege(String mvcName, Context sessionContext) throws TranFailException {
        try {
            Map userPrivilegeMap = (Map) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_TABLE);
            if (userPrivilegeMap == null) {
                Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
            }
            String actionBusinessCode = PBStandard.getActionBusinessCode(String.valueOf(mvcName) + ".do");
            String businessCode = actionBusinessCode;
            if (actionBusinessCode != null) {
                if (!userPrivilegeMap.containsKey(businessCode)) {
                    Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                    throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
                }
                Integer count = (Integer) userPrivilegeMap.get(businessCode);
                userPrivilegeMap.put(businessCode, new Integer(count.intValue() + 1));
            } else {
                businessCode = (String) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_CODE);
            }
            if (businessCode == null) {
                return;
            }
            sessionContext.setDataValue(PBConstants.FIELD_BUSINESS_CODE, businessCode);
        } catch (TranFailException ex) {
            Trace.logError("LifeAction", "交易权限检查异常", ex);
            throw ex;
        } catch (GENEException ex2) {
            Trace.logError("LifeAction", "时间戳错误", ex2);
        }
    }

    public void checkFormValidation(String mvcName, HttpServletRequest request) throws TranFailException {
        TranFailException formValidationConfig = FormValidationProvider.getFormValidationConfig(mvcName);
        if (formValidationConfig != null) {
            try {
                if (!FormValidationProvider.doCheck(FormValidationProvider.getValidationInputMap(formValidationConfig, request))) {
                    Trace.logError("LifeAction", "数据验证失败");
                    formValidationConfig = LifeConstants.EXCEPTION_INVALID_FORMDATA;
                    throw formValidationConfig;
                }
            } catch (TranFailException ex) {
                Trace.log(formValidationConfig);
                throw new TranFailException(ex.getErrorCode(), ex.getShowMessage());
            }
        }
    }

    public void checkHttpGENESID(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String SessionhttpSID = (String) sessionContext.getDataValue("http_sessionId");
            String httpSID = request.getSession().getId();
            if (SessionhttpSID == null || SessionhttpSID == null || !SessionhttpSID.equals(httpSID)) {
                Trace.logWarning("LifeAction", "Session无效，请重新登录！");
                throw new TranFailException("EBLN1001", "Session无效，请重新登录", false);
            }
        } catch (GENEException unused) {
            throw new TranFailException("EBLN1001", "Session无效，请重新登录", false);
        }
    }

    public void checkClientIP(HttpServletRequest request, Context sessionContext) throws TranFailException {
        try {
            String sessionClientIP = (String) sessionContext.getDataValue(PBConstants.FIELD_USER_IP);
            String clientIP = LifeClientRequest.getClientIP(request);
            if (sessionClientIP == null || sessionClientIP.length() == 0 || !sessionClientIP.equals(clientIP)) {
                Trace.logWarning("LifeAction", "非法IP地址，请重新登录！");
                throw new TranFailException("EBLN1001", "非法IP地址，请重新登录", false);
            }
        } catch (GENEException unused) {
            throw new TranFailException("EBLN1001", "非法IP地址，请重新登录", false);
        }
    }

    public void RECORD_USER_BEHAVIOR(HttpServletRequest request, Context sessionContext, String mvcName) {
    }

    public void checkFlowTrace(String mvcName, Context sessionContext) throws TranFailException {
    }

    public void checkUserPrivilege(HttpServletRequest request, String mvcName, Context sessionContext) throws TranFailException {
        try {
            Map userPrivilegeMap = (Map) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_TABLE);
            if (userPrivilegeMap == null) {
                Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
            }
            String actionBusinessCode = PBStandard.getActionBusinessCode(String.valueOf(mvcName) + ".do");
            String businessCode = actionBusinessCode;
            if (actionBusinessCode != null) {
                if (!userPrivilegeMap.containsKey(businessCode)) {
                    Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                    throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
                }
                Integer count = (Integer) userPrivilegeMap.get(businessCode);
                userPrivilegeMap.put(businessCode, new Integer(count.intValue() + 1));
            } else {
                String parameter = request.getParameter("linkBusinessCode");
                businessCode = parameter;
                if (parameter == null) {
                    businessCode = (String) sessionContext.getDataValue(PBConstants.FIELD_BUSINESS_CODE);
                } else if (!userPrivilegeMap.containsKey(businessCode)) {
                    Trace.logWarning("LifeAction", "EBLN0005::交易权限不足");
                    throw LifeConstants.EXCEPTION_INVALID_PRIVILEGE;
                }
            }
            if (businessCode == null) {
                return;
            }
            sessionContext.setDataValue(PBConstants.FIELD_BUSINESS_CODE, businessCode);
        } catch (TranFailException ex) {
            Trace.logError("LifeAction", "交易权限检查异常", ex);
            throw ex;
        } catch (GENEException ex2) {
            Trace.logError("LifeAction", "时间戳错误", ex2);
        }
    }

    public void verifFormData(String mvcName, HttpServletRequest request, Context sessionContext) throws TranFailException {
    }
}
